# owopkg
my PyPI pkg build/deploier

## how 2 use

install : `pip install owopkg`
using : `python -m owopkg`

### using example

builds : `python -m owopkg build bdist_wheel`
deploy : `python -m owopkg deploy`

## feedback

if you aren't beginner, using uv.